Python Module Index — lsqfit 4.8.4 documentation

### Navigation

- index
- modules |
- lsqfit 4.8.4 documentation »

# Python Module Index

g | l

| g |
| `gvar` | Correlated Gaussian random variables.
| `gvar.dataset` | Tools for analyzing collections of random samples.
| `gvar.powerseries` | Power series arithmetic and evaluation.
| l |
| `lsqfit` | Nonlinear least squares fitting.

### Navigation

- index
- modules |
- lsqfit 4.8.4 documentation »